@@ -1,16 +1,27 @@
 #' @inheritParams rmarkdown::pdf_document
 #' @rdname tintHtml
 tintPdf <- function(fig_width = 4, fig_height = 2.5, fig_crop = TRUE,
-                    dev = 'pdf', highlight = 'default',
+                    dev = 'pdf', highlight = 'tango',
                     citation_package = 'natbib', latex_engine = 'pdflatex', ...) {
     tintPdfCreate('tufte-handout', fig_width, fig_height, fig_crop,
                   dev, highlight, citation_package, ...)
 }
 
+#' @inheritParams rmarkdown::pdf_document
+#' @rdname tintHtml
+tintBook <- function(fig_width = 4, fig_height = 2.5, fig_crop = TRUE,
+                    dev = 'pdf', highlight = 'tango',
+                    citation_package = 'natbib', latex_engine = 'pdflatex', ...) {
+    tintPdfCreate('tufte-book', fig_width, fig_height, fig_crop,
+                  dev, highlight, citation_package,
+                  template_resources("tintBook", "tintBook-template.tex"), ...)
+}
+
+
 tintPdfCreate <- function(documentclass = c('tufte-handout', 'tufte-book'),
                           fig_width = 4, fig_height = 2.5, fig_crop = TRUE,
                           dev = 'pdf', highlight = 'default', citation_package = 'natbib',
-                          template = template_resources('pdf', 'tintPdf-template.tex'), ...) {
+                          template = template_resources('tintPdf', 'tintPdf-template.tex'), ...) {
 
     ## resolve default highlight
     if (identical(highlight, 'default')) highlight = 'pygments'
@@ -25,7 +36,7 @@ tintPdfCreate <- function(documentclass = c('tufte-handout', 'tufte-book'),
     documentclass = match.arg(documentclass)
     format$pandoc$args <- c(
         format$pandoc$args, '--variable', paste0('documentclass:', documentclass),
-        if (documentclass == 'tufte-book') '--chapters'
+        if (documentclass == 'tufte-book') "--top-level-division=chapter"
     )
 
     knitr::knit_engines$set(marginfigure = function(options) {
